@@ -1,6 +1,6 @@
 package Net::Appliance::Session;
 BEGIN {
-  $Net::Appliance::Session::VERSION = '3.111530';
+  $Net::Appliance::Session::VERSION = '3.111590';
 }
 
 use Moose;
@@ -49,6 +49,7 @@ foreach my $slot (qw/
         required => 0,
         reader => "get_$slot",
         writer => "set_$slot",
+        predicate => "has_$slot",
     );
 }
 
@@ -94,6 +95,7 @@ has 'nci' => (
         set_global_log_at
         prompt_looks_like
         find_prompt
+        add_library
     /],
 );
 
@@ -124,13 +126,13 @@ Net::Appliance::Session - Run command-line sessions to network appliances
 
 =head1 VERSION
 
-version 3.111530
+version 3.111590
 
 =head1 IMPORTANT NOTE ABOUT UPGRADING FROM VERSION 2.x
 
 Between version 2.x and 3.x of this module the programmer's interface changed
 in a number of ways. If you have existing code to migrate to this new version,
-please see the L<Upgrading|Net::Appliance::Session::Manual::Upgrading>
+please see the L<Upgrading|Net::Appliance::Session::APIv2>
 document which details all steps necessary.
 
 =head1 SYNOPSIS
@@ -138,7 +140,7 @@ document which details all steps necessary.
  use Net::Appliance::Session;
  
  my $s = Net::Appliance::Session->new({
-     personality => 'cisco',
+     personality => 'ios',
      transport => 'SSH',
      host => 'hostname.example',
      privileged_paging => 1, # only if using ASA/PIX OS 7+
@@ -146,9 +148,9 @@ document which details all steps necessary.
  });
  
  eval {
-     $s->connect({name => 'username', password => 'loginpass'});
+     $s->connect({ username => 'username', password => 'loginpass' });
  
-     $s->begin_privileged('privilegedpass');
+     $s->begin_privileged({ password => 'privilegedpass' });
      print $s->cmd('show access-list');
      $s->end_privileged;
  };
@@ -165,10 +167,9 @@ network appliance. There is special support for moving into "privileged" mode
 and "configure" mode, along with the ability to send commands to the connected
 device and retrieve returned output.
 
-There are other CPAN modules that cover similar ground, including Net::SSH and
-Net::Telnet::Cisco, but they are less robust or do not handle native SSH,
-Telnet and Serial Line connections with a single interface on both Unix and
-Windows platforms.
+There are other CPAN modules that cover similar ground, but they are less
+robust and do not handle native SSH, Telnet and Serial Line connections with a
+single interface on both Unix and Windows platforms.
 
 Built-in commands come from a phrasebook which supports many network device
 vendors (Cisco, HP, etc) or you can install a new phrasebook. Most phases of
@@ -176,15 +177,15 @@ the connection are configurable for different device behaviours.
 
 =head1 METHODS
 
-As in the synopsis above, the first step is to create a new instance. As in
-the synopsis above, recommended practice is to wrap all other method calls in
-a Perl C<eval> block to catch errors (typically time-outs waiting for CLI
-response).
+As in the synopsis above, the first step is to create a new instance.
+Recommended practice is to wrap all other method calls in a Perl C<eval> block
+to catch errors (typically time-outs waiting for CLI response). For a
+demonstration of usage, see the example script shipped with this distribution.
 
 =head2 Net::Appliance::Session->new( \%options )
 
  my $s = Net::Appliance::Session->new({
-     personality => 'cisco',
+     personality => 'ios',
      transport => 'SSH',
      host => 'hostname.example',
  });
@@ -197,10 +198,9 @@ options are required, others optional:
 =item C<< personality => $name >> (required)
 
 Tells the module which "language" to use when talking to the connected device,
-for example C<cisco> for Cisco IOS devices. There's a list of all the
-supported platforms in the
-L<Phrasebook|Net::CLI::Interact::Manual::Phrasebook> documentation. It's also
-possible to write new phrasebooks.
+for example C<ios> for Cisco IOS devices. There's a list of all the supported
+platforms in the L<Phrasebook|Net::CLI::Interact::Manual::Phrasebook>
+documentation. It's also possible to write new phrasebooks.
 
 =item C<< transport => $backend >> (required)
 
@@ -257,7 +257,7 @@ how the device is configured, and how you have configured this module to act.
 If it looks like the device presented a Username prompt. and you don't pass
 the username a Perl exception will be thrown.
 
-The password is cached within the module for possbible use later on when
+The password is cached within the module for possible use later on when
 entering "privileged" mode.
 
 =back
@@ -308,9 +308,9 @@ one item.
 To handle more complicated interactions, for example commands which prompt for
 confirmation or optional parameters, you should use a Macro. These are set up
 in the phrasebook and issued via the C<< $s->macro($name) >> method call. See
-the L<Phrasebook|Net::CLI::Interact::Phrasebook#PHRASEBOOK_FORMAT> and
-L<Cookbook|Net::CLI::Interact::Manual::Cookbook#Macros> manual pages for
-further details.
+the L<Phrasebook|Net::CLI::Interact::Phrasebook> and
+L<Cookbook|Net::CLI::Interact::Manual::Cookbook> manual pages for further
+details.
 
 =head2 close
 
@@ -388,7 +388,7 @@ behaviour.
 To see a log of all the processes within this module, and a copy of all data
 sent to and received from the device, call the following method:
 
- $s->set_global_log_at( 'debug' );
+ $s->set_global_log_at('debug');
 
 In place of C<debug> you can have other log levels, and via the embedded
 L<Logger|Net::CLI::Interact::Logger> at C<< $s->nci->logger >> it's possible
